align_of_val

Function align_of_val 

1.6.0 (const: 1.85.0) · Source
pub const fn align_of_val<T: ?Sized>(val: &T) -> usize
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Returns the ABI-required minimum alignment of the type of the value that val points to in bytes.

Every reference to a value of the type T must be a multiple of this number.

Examples

assert_eq!(4, align_of_val(&5i32));